% =========================================================================
% Title       : Wrapper for Channel Decoders
% File        : decoder.m
% -------------------------------------------------------------------------
% Description :
%   This file performs (de-)puncturing and calls the chosen channel
%   decoder. Note that this version only contains a max-log BCJR
%   implementation written in Mex/Matlab. 
% ------------------------------------------------------------------------- 
% Revisions   :
%   Date       Version  Author  Description
%   07-apr-13  1.4      studer  cleanup
%   17-sep-07  1.3      studer  simplified/cleanup for student projects
%   19-sep-06  1.2      studer  removed some channel decoders
%   17-aug-06  1.1      studer  added BCJR as benchmark
%   07-jun-06  1.0      studer  partially adopted from ofdm_sim
% -------------------------------------------------------------------------
%   (C) 2013 Christoph Studer (e-mail: studer@rice.eduu)     
% =========================================================================

function [LLR_P1,binary_data_hat] = decoder(TxRx,LLR_E1)

  for nrx=1:TxRx.Nrx

    % -- de-interleaving
    LLR_A2(1,TxRx.Code.InterleaverPerm(nrx,:)) = LLR_E1(nrx,:);   
          
    % -- de-puncturing
    LLR_A2_punctured = zeros(1,2*length(LLR_A2(1,:))*TxRx.Code.Rate);    
    LLR_A2_punctured(TxRx.Code.Puncturing.Index) = LLR_A2;

    [LLR_P1(nrx,:),binary_data_hat(nrx,:)] = BCJR(TxRx.Code.trellis,LLR_A2_punctured); 
  
  end
  
return
