% =========================================================================
% Title       : Data detector
% File        : detector.m
% -------------------------------------------------------------------------
% Description :
%   This file performs soft-output data detection using the max-log 
%   approximation. 
% ------------------------------------------------------------------------- 
% Revisions   :
%   Date       Version  Author  Description
%   07-apr-13  1.0      studer  file created
% -------------------------------------------------------------------------
%   (C) 2013 Christoph Studer (e-mail: studer@rice.eduu)     
% =========================================================================

function [LLR_E1,complexity_log] = detector(TxRx,yN,HN,N0)
  
  % -- initialization 
  complexity_log = 0; 
  bin_array = sign(mexde2bi([0:2^(TxRx.Modulation_order)-1],TxRx.Modulation_order)-0.5);  
   
  % -- perform detection for each terminal
  for nrx=1:TxRx.Nrx
   
    for n=1:TxRx.Nused
      Metrics = abs(yN(nrx,n)-TxRx.Constellations_norm).^2/N0;
    
      % -- compute max-log LLRs
      for b=[1:TxRx.Modulation_order]
        pMin = inf; nMin = inf;
        for z=[1:2^(TxRx.Modulation_order)]          
          if (bin_array(z,b)==1)
            pMin = min(pMin,Metrics(z));
          else
            nMin = min(nMin,Metrics(z));          
          end                                
        end            
        LLR_E1(nrx,(n-1)*TxRx.Modulation_order+b) = nMin-pMin;
      end 
            
    end
            
  end  
  
return
