% =========================================================================
% Title       : Example Script for Simulator
% File        : PAR_8x64_16QAM_Tap4_PMP.m
% -------------------------------------------------------------------------
% Description :
%   Starts a simulation using the large-scale MIMO framework 
% ------------------------------------------------------------------------- 
% Revisions   :
%   Date       Version  Author  Description
%   07-apr-13  1.0      studer  file created
% -------------------------------------------------------------------------
%   (C) 2013 Christoph Studer (e-mail: studer@rice.edu)     
% =========================================================================

function PAR_8x64_16QAM_Tap4_PMP(RunID)

  % -- simulation setup
  TxRx.Sim.name = 'PAR_8x64_16QAM_Tap4_PMP';
  TxRx.Sim.MaxPER = 1000;        % Maximum required PER 
  TxRx.Sim.nr_of_packets = 1000; % Number of packets
  TxRx.Sim.nr_of_symbols = 1;    % Number of OFDM symbols per packet
  TxRx.Sim.SNR_dB_list = [-6:2:10];    
  
  % -- system configuration
  TxRx.Modulation_order = 4; % Modulation scheme: BPSK (1), QPSK (2), 16-QAM (4), 64-QAM (6)
  TxRx.Nrx = 8;             % Number of receivers (terminals)
  TxRx.Ntx = 64;            % Number of transmit antennas (at basestation)
  TxRx.N = 128;              % Nr. of subcarriers
  TxRx.ToneMap=[-58:-54,-52:-26,-24:-12,-10:-2,2:10,12:24,26:52,54:58]+63+1; % 40MHz IEEE 802.1n   

  % -- select signal-shaping strategy
  TxRx.Shaping = 'PMP';
  TxRx.ShapingAlg.lambda = 0.25;
  TxRx.ShapingAlg.iter = 1000;
  TxRx.ShapingAlg.tol = 1e-5;
  
  % -- code and decoder properties
  TxRx.Code.K = 7;                   % Constraint Length
  TxRx.Code.generators = [133  171]; % Generator Polynomial      
  TxRx.Code.Rate = 1/2;              % code rates '1/2','3/4','2/3','5/6'
  
  % -- channel model
  TxRx.Channel.Model = 'Tap'; % 'Tap' (uniform profile)
  TxRx.Channel.Ntaps = 4; 

  % -- start simulation
  err_sim(TxRx,RunID);

return
  
