% =========================================================================
% Title       : Example Script for Matlab Error-Rate Plots
% File        : err_plot.m
% -------------------------------------------------------------------------
% Description :
%   Simple example of a average symbol error rate (SER) plot.
% ------------------------------------------------------------------------- 
% Revisions   :
%   Date       Version  Author  Description
%   07-apr-13  1.0      studer  file created
% -------------------------------------------------------------------------
%   (C) 2013 Christoph Studer (e-mail: studer@rice.edu)     
% =========================================================================

clear all
clc

% =========================================================================

% -- collect max. 10 files
number = 10;

% -- load simulation data and consolidate (*** does not consolidate stats ***)
LS = consolidate('PAR_8x64_16QAM_Tap4_LS',number);
MF = consolidate('PAR_8x64_16QAM_Tap4_MF',number);
PMP = consolidate('PAR_8x64_16QAM_Tap4_PMP',number);

% =========================================================================

%== BER plot
figure(1)
semilogy(LS.TxRx.Sim.SNR_dB_list,mean(LS.SER,2),'bo-','Linewidth',2)
hold on
semilogy(MF.TxRx.Sim.SNR_dB_list,mean(MF.SER,2),'mv-','Linewidth',2)
semilogy(PMP.TxRx.Sim.SNR_dB_list,mean(PMP.SER,2),'rx-','Linewidth',2)
hold off
axis([-6 10 1e-3 1])
grid on
set(gca,'FontSize',12)
xlabel('SNR [dB]','FontSize',12)
ylabel('average SER','FontSize',12)
legend('ZF precoding','MF precoding','PMP',1)

% -- write eps file to disk
% print -deps 'plots/4tap.eps'

% == PAPR plot
figure(2)
x = 0:0.5:20; 
semilogy(x,1-cdfgen(x,10*log10(LS.Stat.PAR)),'b-','Linewidth',2); 
hold on
semilogy(x,1-cdfgen(x,10*log10(MF.Stat.PAR)),'m-','Linewidth',2);
semilogy(x,1-cdfgen(x,10*log10(PMP.Stat.PAR)),'r-','Linewidth',2);
hold off
axis([0 15 1e-4 1]); 
grid on; 
set(gca,'FontSize',12)
xlabel('per-antenna Tx-PAR [dB]','FontSize',12); 
ylabel('complementary CDF','FontSize',12)
legend('ZF precoding','MF precoding','PMP',3)

% =========================================================================
