% =========================================================================
% Title       : Consolidate Simulation results
% File        : consolidate.m
% -------------------------------------------------------------------------
% Description :
%   Collects at most "number" simulation results and computes avereage
%   error rates and complexities. 
% ------------------------------------------------------------------------- 
% Revisions   :
%   Date       Version  Author  Description
%   07-apr-13  1.1      studer  cleanup
%   10-aug-06  1.0      studer  adapted from ofdm_sim environment
% -------------------------------------------------------------------------
%   (C) 2013 Christoph Studer (e-mail: studer@rice.edu)     
% =========================================================================

function Out = consolidate(filename,number);
  disp(sprintf('consolidate %s ...',filename));
  k = 0;
  for i=1:number
    fullname = ['results/',filename,'_',num2str(i-1),'.mat'];
    % -- check whether file exists
    if exist(fullname)>0
      tmp = load(fullname);
      if k==0
        ptype = tmp;
        BERunc = ptype.Results.BERunc;
        SERunc = ptype.Results.SERunc;
        PERunc = ptype.Results.PERunc;
        BER = ptype.Results.BER;
        SER = ptype.Results.SER;
        PER = ptype.Results.PER;
        PAR = ptype.Results.Stat.PAR;
        OPR = ptype.Results.Stat.OPR;
        NrOfSimPackets = ptype.Results.NrOfSimPackets;
      else
        BERunc = BERunc + tmp.Results.BERunc;
        SERunc = SERunc + tmp.Results.SERunc;
        PERunc = PERunc + tmp.Results.PERunc;
        BER = BER + tmp.Results.BER;
        SER = SER + tmp.Results.SER;
        PER = PER + tmp.Results.PER;
        PAR = [PAR tmp.Results.Stat.PAR];
        OPR = [OPR tmp.Results.Stat.OPR];      
        NrOfSimPackets = NrOfSimPackets + tmp.Results.NrOfSimPackets;
      end
      k=k+1;
    end
  end
  % -- average and compute output
  ptype.Results.BERunc = BERunc/k;
  ptype.Results.SERunc = SERunc/k;
  ptype.Results.PERunc = PERunc/k; 
  ptype.Results.NrOfSimPackets = NrOfSimPackets;
  ptype.Results.Stat.PAR = PAR;
  ptype.Results.Stat.OPR = OPR;  
  disp(sprintf('%i packets simulated.\n',NrOfSimPackets));
  Out = ptype.Results;
return
